limis
=====
![build status](https://travis-ci.org/limis-project/limis.svg?branch=master)

limis is a light microservice framework built in [Python](https://www.python.org/) and powered by 
[Tornado](https://www.tornadoweb.org/). The project is currently in active development and should be considered alpha
grade at the moment. Features are being added and removed and expect the API to change frequently.